@@ -548,7 +548,7 @@ def generate_ddf_scheduled_obs(
                     obs["scheduler_note"] = "DD:%s" % ddf_name.replace("_a", "_b")
                     obs["target_name"] = "DD:%s" % ddf_name.replace("_a", "_b")
                     obs["science_program"] = "DD"
-                    obs["observation_reason"] = "FBS"
+                    obs["observation_reason"] = "DD:%s" % ddf_name.replace("_a", "_b")
 
                     obs["mjd_tol"] = mjd_tol
                     obs["dist_tol"] = dist_tol
@@ -573,7 +573,7 @@ def generate_ddf_scheduled_obs(
                     obs["scheduler_note"] = "DD:%s" % ddf_name
                     obs["target_name"] = "DD:%s" % ddf_name
                     obs["science_program"] = "DD"
-                    obs["observation_reason"] = "FBS"
+                    obs["observation_reason"] = "DD:%s" % ddf_name
 
                     obs["mjd_tol"] = mjd_tol
                     obs["dist_tol"] = dist_tol
