@@ -55,8 +55,8 @@ except ImportError:
         token: str | None = None
 
         if token_file is not None:
-            with open("token_file", "r") as f:
-                token = f.read()
+            with open(token_file, "r") as token_io:
+                token = token_io.read()
         elif "ACCESS_TOKEN" in os.environ:
             token = os.environ.get("ACCESS_TOKEN")
 
@@ -91,6 +91,9 @@ def query_consdb(
     url : `str`, optional
         The ConsDB REST API URL, or ``None`` to guess.
         Defaults to ``None``.
+    token_file : `str` or `None`
+        The file from which to read the access token.
+        ``None`` for default.
 
     Returns
     -------
@@ -101,6 +104,9 @@ def query_consdb(
         url = _guess_consdb_endpoint()
     assert url is not None
 
+    if token_file is None:
+        token_file = os.environ.get("ACCESS_TOKEN_FILE", None)
+
     auth = _get_auth(token_file)
     params = {"query": query}
 
@@ -152,11 +158,19 @@ class ConsDBVisits(ABC):
     num_nights : `int`
         The number of nights (up to and including day_obs)
         for which to get visits. Defaults to 1.
+    token_file : `str` or `None`
+        File from which to load the token. If `None`, use the ``lsst.rsp``
+        (if available) or the ``ACCESS_TOKEN`` environment variable.
+        Defaults to `None`.
+    constraints : `str`
+        Additional constraints in the SQL query to send to consdb.
     """
 
     day_obs: str | int
     url: str | None = None
     num_nights: int = 1
+    token_file: str | None = None
+    constraints: str = ""
 
     def _have_numeric_values(self, column) -> bool:
         if column not in self.consdb_visits.columns:
@@ -335,12 +349,20 @@ class ConsDBVisits(ABC):
             """
 
         visit_columns = (
-            query_consdb(columns_query(f"visit{self.num_exposures}", self.instrument), url=self.url)
+            query_consdb(
+                columns_query(f"visit{self.num_exposures}", self.instrument),
+                url=self.url,
+                token_file=self.token_file,
+            )
             .loc[:, "column_name"]
             .values
         )
         ql_columns = (
-            query_consdb(columns_query(f"visit{self.num_exposures}_quicklook", self.instrument), url=self.url)
+            query_consdb(
+                columns_query(f"visit{self.num_exposures}_quicklook", self.instrument),
+                url=self.url,
+                token_file=self.token_file,
+            )
             .loc[:, "column_name"]
             .values
         )
@@ -363,7 +385,10 @@ class ConsDBVisits(ABC):
                 AND v.day_obs <= {self.day_obs_int}
                 AND v.day_obs > {prior_day_obs_int}
         """
-        return query_consdb(consdb_visits_query, self.url)
+        if len(self.constraints) > 0:
+            consdb_visits_query += f" AND ({self.constraints})"
+
+        return query_consdb(consdb_visits_query, self.url, self.token_file)
 
     @cached_property
     def visit_id(self) -> pd.Series:
@@ -767,7 +792,8 @@ class ConsDBVisits(ABC):
         night : `int`
             The night of the survey.
         """
-        night: int = 1 + self.day_obs_mjd - int(np.floor(SURVEY_START_MJD))
+        ref_mjd = min(np.min(self.obs_start_mjd), SURVEY_START_MJD)
+        night: int = (np.floor(self.obs_start_mjd - 0.5) - np.floor(ref_mjd - 0.5)).astype(int)
         return night
 
     @cached_property
